/**
  *  \file client/scr-planet.cc
  *  \brief Planet Screen
  *
  *  (c) 2001-2011 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/screens.h"
#include "client/actions.h"
#include "client/cscreen.h"
#include "client/dlg-objsel.h"
#include "client/wscanchart.h"
#include "client/tiles/planetoverview.h"
#include "game/global.h"
#include "game/planet.h"
#include "int/if/planetif.h"
#include "int/intglobal.h"
#include "int/keymap.h"
#include "resmgr/resid.h"
#include "ui/msgbox.h"
#include "ui/uiglobal.h"
#include "util/nls.h"
#include "client/tiles.h"

namespace {
    class WPlanetScreen : public WControlScreen {
     public:
        WPlanetScreen();
        ~WPlanetScreen();
        void update();
        void setScriptContext();
    };
}

/** Choose a planet. Displays the dialog if necessary and lets the
    user choose a planet.
    \return planet Id, zero if no planet or cancelled */
int
choosePlanet()
{
    int nplanets = global_planet_type.getCount();
    if (nplanets == 0) {
        messageBox(_("You do not have any planets. "
                     "Unload colonists from a starship to a planet to colonize it."),
                   _("Planets"));
        return 0;
    } else if (nplanets == 1) {
        return global_planet_type.getCurrent();
    } else {
        GAliasObjectType aot(global_planet_type);
        WPlanetOverviewTile bot(aot);
        WObjectSelectionDialog dlg(_("Select Planet"), "pcc2:unitsel", aot);
        dlg.addWidget(bot);
        dlg.pack();
        ui_root->centerWidget(dlg);
        if (ui_root->runModal(dlg) == cm_Enter)
            return aot.getCurrent();
        else
            return 0;
    }
}

/***************************** WPlanetScreen *****************************/

/** \class WPlanetScreen
    \brief Planet Control Screen

    Standard control screen for a player's planet. */

/** Constructor. */
WPlanetScreen::WPlanetScreen()
    : WControlScreen(global_planet_type, WScreenId::PlanetScreen)
{
    createTileLayout(*this, "PLANETSCREEN", global_planet_type);
    addChart(holder.add(new WScannerChartWidget()));
    setKeymap(IntKeymap::getKeymapByName("PLANETSCREEN"));
}

WPlanetScreen::~WPlanetScreen()
{ }

void
WPlanetScreen::update()
{
    if (GMapObject* mo = dynamic_cast<GMapObject*>(&getType().getObject(getType().getCurrent()))) {
        getScanner().getChart()->setCenterPosition(mo->getPos());
        getScanner().getChart()->setScannerOrigin(mo->getPos());
        getScanner().getChart()->setScannerTarget(mo->getPos());
    }
}

void
WPlanetScreen::setScriptContext()
{
    global_contexts.push_back(new IntPlanetContext(getType().getCurrent()));
}

void
doPlanetScreen()
{
    WPlanetScreen().runScreen();
}
