/**
  *  \file client/screens/basetaskscreen.cc
  *  \brief Starbase Task Screen
  *
  *  (c) 2001-2011 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/screens/basetaskscreen.h"
#include "client/screens/planettaskscreen.h"
#include "client/tasksupport.h"
#include "client/wscanchart.h"
#include "cpluslib/format.h"
#include "game/global.h"
#include "game/obj.h"
#include "game/planet.h"
#include "int/exec.h"
#include "int/if/planetif.h"
#include "int/intglobal.h"
#include "int/process.h"
#include "util/nls.h"

namespace {
    class WBaseAutoTaskScreen : public WAutoTaskScreen {
     public:
        WBaseAutoTaskScreen(WPlanetAutoTaskType& type);
        void update();
        void setScriptContext();
    };
}

/************************** WBaseAutoTaskScreen **************************/

WBaseAutoTaskScreen::WBaseAutoTaskScreen(WPlanetAutoTaskType& type)
    : WAutoTaskScreen(type, WScreenId::BaseTaskScreen)
{
    createTileLayout(*this, "BASETASKSCREEN", type);
    addChart(holder.add(new WScannerChartWidget()));
    setKeymap(IntKeymap::getKeymapByName("BASETASKSCREEN"));
}

void
WBaseAutoTaskScreen::update()
{
    if (GMapObject* mo = dynamic_cast<GMapObject*>(&getType().getObject(getType().getCurrent()))) {
        WScannerChartWidget& chart = *getScanner().getChart();
        chart.setCenterPosition(mo->getPos());
        chart.setScannerOrigin(mo->getPos());
        chart.setScannerTarget(mo->getPos());
    }
}

void
WBaseAutoTaskScreen::setScriptContext()
{
    global_contexts.push_back(new IntPlanetContext(type.getCurrent()));
}


void
doBaseAutoTaskScreen()
{
    WPlanetAutoTaskType at(global_base_type, IntExecutionContext::pkBaseTask);
    WBaseAutoTaskScreen screen(at);
    at.init();
    screen.runScreen();
    at.done();
}
