/**
  *  \file client/widgets/chartwidget.h
  *  \brief Starchart Widget
  *
  *  (c) 2001-2011 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_CLIENT_WIDGETS_CHARTWIDGET_H
#define PCC_V2_CLIENT_WIDGETS_CHARTWIDGET_H

#include "client/chart.h"
#include "ui/ui.h"
#include "game/coord.h"

/*! \class WChartWidget
    \brief Static piece of starchart.

    This just displays a static piece of starchart, without any user
    interaction. It can be made invalid, in this case it will not
    display anything. */
class WChartWidget : public UIWidget {
    GChartViewport viewport;
    bool is_valid;

 protected:
    // Draw
    virtual void drawPre(GfxCanvas& can);
    virtual void drawPost(GfxCanvas& can);

    // Viewport access
    const GChartViewport& getViewport() const;
    GChartViewport& getViewport();

 public:
    WChartWidget();
    ~WChartWidget();
    void drawContent(GfxCanvas& can);

    // Coordinate access
    void setCenterPosition(GPoint pt);
    GPoint getCenterPosition() const;
    bool isValid() const;
    void setInvalid();

    // Further control
    bool zoomIn();
    bool zoomOut();
};


/** Get current center position. Only meaningful if isValid() is true.
    \return game coordinates */
inline GPoint
WChartWidget::getCenterPosition() const
{
    return viewport.center;
}

/** Check whether this widget has valid coordinates. */
inline bool
WChartWidget::isValid() const
{
    return is_valid;
}

/** Get current chart viewport. For use during drawPre/drawPost. */
inline const GChartViewport&
WChartWidget::getViewport() const
{
    return viewport;
}

/** Get current chart viewport. For use during drawPre/drawPost. */
inline GChartViewport&
WChartWidget::getViewport()
{
    return viewport;
}


#endif
