/**
  *  \file client/widgets/reginfo.cc
  *  \brief WRegInfoDisplay widget
  *
  *  (c) 2001-2011 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/widgets/reginfo.h"
#include "ui/uiglobal.h"
#include "gfx/gfxcontext.h"
#include "util/unicodechars.h"
#include "util/nls.h"

/** Constructor. Makes a blank object that displays nothing. */
WRegInfoDisplay::WRegInfoDisplay()
    : is_clear(true)
{ }

WRegInfoDisplay::~WRegInfoDisplay()
{ }

void
WRegInfoDisplay::getLayoutInfo(LayoutInfo& li)
{
    li.min_size = li.pref_size = font_sizes[FONT_NORMAL].scaledBy(20, 1);
    li.flags = li_FlexibleH;
}

void
WRegInfoDisplay::drawContent(GfxCanvas& can)
{
    GfxContext ctx;
    ctx.useColorScheme(getSkin());
    ctx.useCanvas(can);
    ctx.useFont(*fonts[FONT_NORMAL]);
    drawBackground(ctx, getExtent());
    if (!is_clear) {
        string_t flag, info;
        if (!reg_info.isValid()) {
            flag = UTF_BALLOT_CROSS;
            info = _("No registration in this directory!");
            ctx.setColor(UIColor::tc_Red);
        } else if (!reg_info.isRegistered()) {
            flag = UTF_RIGHT_POINTER;
            info = _("Unregistered");
            ctx.setColor(UIColor::tc_Yellow);
        } else {
            flag = UTF_CHECK_MARK;
            info = reg_info.getRegStr1();
            ctx.setColor(UIColor::tc_Green);
        }

        outText(ctx, extent.x, extent.y, flag);
        // ctx.setColor(UIColor::tc_Static); /* I'm not yet sure what looks better */

        const int dx = font_ems[FONT_NORMAL]*6/5;
        outTextF(ctx, extent.x + dx, extent.y, extent.w - dx, info);
    }
    can.update(getExtent());
}

/** Clear. Make this object display nothing. */
void
WRegInfoDisplay::clear()
{
    is_clear = true;
    drawWidget();
}

/** Initialize from directory. Reads the registration information
    contained in the specified directory, and displays it in this
    widget.
    \param dir Directory to display */
void
WRegInfoDisplay::initFromDirectory(Directory& dir)
{
    is_clear = false;
    reg_info.initFromDirectory(dir, false);
    drawWidget();
}

/** Initialize from GRegInfo object. Copies the object and displays it.
    \param info Object to display */
void
WRegInfoDisplay::initRegInfo(const GRegInfo& info)
{
    is_clear = false;
    reg_info = info;
    drawWidget();
}
