/**
  *  \file io/glob.h
  *  \brief Globbing
  *
  *  (c) 2001-2011 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_IO_GLOB_H
#define PCC_V2_IO_GLOB_H

#include "cpluslib/string.h"
#include "util/except.h"

class FileNameMatcher;

class FileNamePattern {
    FileNameMatcher* rep;

 public:
    FileNamePattern();
    FileNamePattern(const string_t name);
    FileNamePattern(const FileNamePattern& other);
    FileNamePattern& operator=(const FileNamePattern& other);
    ~FileNamePattern();

    void setPattern(const string_t pattern);
    bool hasWildcard() const;
    string_t getFileName() const;
    bool match(const string_t filename) const;

    static string_t getAllFilesPattern();
    static string_t getAllFilesWithExtensionPattern(string_t ext);
    static string_t getSingleFilePattern(string_t name);
};

class FileNamePatternException : public UserException {
 public:
    FileNamePatternException(const string_t& awhat);
    FileNamePatternException(const char* awhat);
    FileNamePatternException(const FileNamePatternException&);
    ~FileNamePatternException() throw();
};

#endif
